@@ -31,6 +31,7 @@
 #include <arpa/inet.h>
 #include <cerrno>
 #include <cstdio>
+#include <cstring>
 #include <memory>
 #include <netinet/in.h>
 #include <string>
@@ -471,5 +472,3 @@ proxy_start(subnets& nets)
 
   return false;
 }
-
-// arch-tag: d774d4cf-6b7b-4a25-9649-c5da11123554
