@@ -23,6 +23,7 @@
 
 #include <cerrno>
 #include <cstdio>
+#include <cstring>
 #include <fcntl.h>
 #include <netinet/in.h>
 #include <string>
@@ -336,5 +337,3 @@ tcp_half_duplex_handler::on_activity_write(activity act)
     return true;
   }
 }
-
-// arch-tag: 91207afc-6334-41e4-a6a0-3c2aac453597
