@@ -38,6 +38,7 @@
 #include <cerrno>
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
 #include <algorithm>
 
 typedef struct {
@@ -301,5 +302,3 @@ subnets::show_progress()
     fflush (stderr);
   }
 }
-
-// arch-tag: 8d878b32-e911-42a9-b645-8b66c584cf10
